@@ -3,6 +3,7 @@ Wrapper around mypy which prevents the number of typecheck errors from increasin
 but which does not force you to fix them all.
 
 Developed against mypy 0.770
+Verified to work with 0.790
 """
 import json
 import os
@@ -13,16 +14,15 @@ from dataclasses import dataclass
 from typing import List, Optional, Pattern
 
 import mypy.version
-from dataclasses_json import dataclass_json  # type:ignore
+from dataclasses_json.api import DataClassJsonMixin
 
 ALLOWABLE_ERRORS_FILE_NAME = ".mypykaizen.json"
 LINE_SANITIZATION_PATTERN: Pattern[str] = re.compile(r"note: .* defined here$")
 WINDOWS_PATH_START: Pattern[str] = re.compile(r"^[A-Za-z]\:\\")
 
 
-@dataclass_json
 @dataclass
-class AllowableErrors:
+class AllowableErrors(DataClassJsonMixin):
     """Class to keep track of the allowable errors"""
 
     file_version: str = "v1"
@@ -57,6 +57,13 @@ def sanitize_output_lines(output_lines: List[str]) -> List[str]:
     """
 
     def _sanitize_line(line: str) -> Optional[str]:
+        # Mostly defensive:
+        line = line.strip()
+
+        # Handle running in daemon mode
+        if line.lower() == "Daemon started".lower():
+            return None
+
         is_windows_prefixed = bool(WINDOWS_PATH_START.match(line))
         if is_windows_prefixed:
             splitline = line.split(":", maxsplit=2)
@@ -89,9 +96,20 @@ def sanitize_output_lines(output_lines: List[str]) -> List[str]:
 
 
 def main() -> None:
+    _main(["mypy"])
+
+
+def dmain() -> None:
+    """
+    Daemon mode - can be WAY faster
+    """
+    _main(["dmypy", "run", "--"])
+
+
+def _main(entrypoint_commands: List[str]) -> None:
     # Run mypy:
     result = subprocess.run(
-        ["mypy"] + sys.argv[1:],
+        entrypoint_commands + sys.argv[1:],
         text=True,
         # Redirect input/out streams
         stdin=sys.stdin,
@@ -120,7 +138,8 @@ def main() -> None:
         print(f"            current version is {mypy.version.__version__}")
         print()
         allowable_errors.mypy_version = mypy.version.__version__
-        needs_save = True
+
+        # Note that we are not forcing a save just when the version changes.
 
     output_lines = result.stdout.splitlines()
     last_line = output_lines[-1]
@@ -134,10 +153,17 @@ def main() -> None:
         print("mypykaizen: SUCCESS")
 
         # No longer allow any errors:
-        allowable_errors.total_errors = 0
-        allowable_errors.files_in_error = 0
-        allowable_errors.last_full_output = output_lines
-        allowable_errors.save()
+        if allowable_errors.total_errors is None or allowable_errors.total_errors != 0:
+            allowable_errors.total_errors = 0
+            needs_save = True
+        if allowable_errors.files_in_error is None or allowable_errors.files_in_error != 0:
+            allowable_errors.files_in_error = 0
+            needs_save = True
+        if allowable_errors.last_full_output is None or allowable_errors.last_full_output != output_lines:
+            allowable_errors.last_full_output = output_lines
+            needs_save = True
+        if needs_save:
+            allowable_errors.save()
 
         exit(result.returncode)
 
@@ -223,7 +249,9 @@ def main() -> None:
     # Note as coded, that this technically allows you to introduce new type errors if you
     # fix an equal number. This is largely unintentional but does make it super easy to
     # support refactoring usecases where a bunch of line numbers change
-    if not errors_increased:
+    if not errors_increased and (
+        allowable_errors.last_full_output is None or allowable_errors.last_full_output != output_lines
+    ):
         allowable_errors.last_full_output = output_lines
         needs_save = True
 
